pro oxplot_JJA

; data files
datadir = './'
data2000 = datadir + 'ctm.natveg2000.bpch'
data2050 = datadir + 'ctm.natveg2050.bpch'
data2100 = datadir + 'ctm.natveg2100.bpch'

; get grid information
ModelType = 'GCAP'
resolution = 4
ModelInfo = CTM_TYPE( ModelType, reso=resolution)
GridInfo  = CTM_GRID( ModelInfo )
modellayers = 47 ; GEOS-5 reduced grid

saveplot = 1L
png = 0L
outfile = './plots/landcover_ox_JJA.ps'
pngfile = './pngs/landcover_ox_JJA.png'

; get grid information
xarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/xmid) ; generate x grid for plotting
yarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/ymid) ; generate y grid for plotting

Map_Labels, LatLabel, LonLabel, $
Lats=Lats, LatRange=LatRange, $
Lons=Lons, LonRange=LonRange, $
NormLats=NormLats, NormLons=NormLons, $
/MapGrid, _EXTRA=e

open_device, ps=saveplot, filename=outfile, winparam=[0,1000,800], /color

; set Ox data parameters
tracer=2 ; Ox
diagn='IJ-AVG-$'
tau_jun = nymd2tau( 20000601L, 0L )
tau_jul = nymd2tau( 20000701L, 0L )
tau_aug = nymd2tau( 20000801L, 0L )

; extract data set from bpch file
ctm_get_data, datainfo2000_jun, tau0=tau_jun, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2000_jul, tau0=tau_jul, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2000_aug, tau0=tau_aug, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2050_jun, tau0=tau_jun, diagn=diagn, tracer=tracer, filename=data2050
ctm_get_data, datainfo2050_jul, tau0=tau_jul, diagn=diagn, tracer=tracer, filename=data2050
ctm_get_data, datainfo2050_aug, tau0=tau_aug, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2100_jun, tau0=tau_jun, diagn=diagn, tracer=tracer, filename=data2100
ctm_get_data, datainfo2100_jul, tau0=tau_jul, diagn=diagn, tracer=tracer, filename=data2100
ctm_get_data, datainfo2100_aug, tau0=tau_aug, diagn=diagn, tracer=tracer, filename=data2100

; extract data for each month
data_jun2000 = (*(datainfo2000_jun[0].data))[*,*,*,0,0,0]
data_jul2000 = (*(datainfo2000_jul[0].data))[*,*,*,0,0,0]
data_aug2000 = (*(datainfo2000_aug[0].data))[*,*,*,0,0,0]
data_jun2050 = (*(datainfo2050_jun[0].data))[*,*,*,0,0,0]
data_jul2050 = (*(datainfo2050_jul[0].data))[*,*,*,0,0,0]
data_aug2050 = (*(datainfo2050_aug[0].data))[*,*,*,0,0,0]
data_jun2100 = (*(datainfo2100_jun[0].data))[*,*,*,0,0,0]
data_jul2100 = (*(datainfo2100_jul[0].data))[*,*,*,0,0,0]
data_aug2100 = (*(datainfo2100_aug[0].data))[*,*,*,0,0,0]

; declare array to hold calculated average
avg2000_ox = make_array(72L,45L,23L, /float)
avg2050_ox = make_array(72L,45L,23L, /float)
avg2100_ox = make_array(72L,45L,23L, /float)

; loop through all elements in array and calculate 3-month average
for long = 0, 71L DO BEGIN
   for lat = 0, 44L DO BEGIN
      for lev = 0, 22L DO BEGIN
           avg2000_ox[long, lat, lev] = mean([data_jun2000[long, lat, lev], data_jul2000[long, lat, lev], data_aug2000[long, lat, lev]])
           avg2050_ox[long, lat, lev] = mean([data_jun2050[long, lat, lev], data_jul2050[long, lat, lev], data_aug2050[long, lat, lev]])
           avg2100_ox[long, lat, lev] = mean([data_jun2100[long, lat, lev], data_jul2100[long, lat, lev], data_aug2100[long, lat, lev]])
      endfor
   endfor
endfor

; generate plots

multipanel, rows=2, cols=2

MyCt, 33, ncolors=6,sat=1.0, value=1.0, bottom=18, range=[0.1, 1]

; plot 2000 veg
tvmap, avg2000_ox[*,*,0], xarr1, yarr1, $
   position = [0.1, 0.02, 0.90, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.06, 0.95, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   ; bottom = 18, $
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical = 1, $
   c_levels = [15, 20, 30, 40, 50, 65], $
   ; mindata = 15, $
   ; c_levels = [1, 20, 30, 40, 50, 65], $
   toplevelvalue = 72., $
   cbunit = 'ppbv', $
   cbformat = '(I3)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2000 veg'

myct, 'RdBu', /MIDCOLORPRESENT, /WHITE, ncolors=7, /reverse

; plot 2050 veg - 2000 veg
data = avg2050_ox[*,*,0] - avg2000_ox[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.02, 0.89, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.06, 0.94, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.0, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-10, -5, -2, -1, 1, 2, 3], $
   toplevelvalue = 5., $
   cbunit = 'ppbv', $
   cbformat = '(I3)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2050 veg - 2000 veg'
   
; plot 2100 veg - 2050 veg
data = avg2100_ox[*,*,0] - avg2050_ox[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.1, 0.1, 0.90, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.14, 0.95, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-10, -5, -2, -1, 1, 2, 3], $
   toplevelvalue = 5., $
   cbunit = 'ppbv', $
   cbformat = '(I3)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2100 veg - 2050 veg'

; plot 2100 veg - 2000 veg
data = avg2100_ox[*,*,0] - avg2000_ox[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.1, 0.89, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.14, 0.94, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.0, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-10, -5, -2, -1, 1, 2, 3], $
   toplevelvalue = 5., $
   cbunit = 'ppbv', $
   cbformat = '(I3)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2100 veg - 2000 veg'
   
if ( PNG ) then Screen2Png, pngfile
if ( saveplot ) then Close_Device
end
