pro oxplot_annualmean

; create annual mean and annual zonal mean plots for Ox

do_zm = 1L

; data files
datadir = './'
data2000 = datadir + 'ctm.natveg2000.bpch'
data2050 = datadir + 'ctm.natveg2050.bpch'
data2100 = datadir + 'ctm.natveg2100.bpch'

; get grid information
ModelType = 'GCAP'
resolution = 4
ModelInfo = CTM_TYPE( ModelType, reso=resolution)
GridInfo  = CTM_GRID( ModelInfo )
modellayers = 47 ; GEOS-5 reduced grid

saveplot = 1L
png = 0L
outfile = './plots/landcover_ox_annual_mean.ps'
outfile_zm = './plots/landcover_ox_annual_mean_zm.ps'
pngfile = './pngs/landcover_ox_annual_mean.png'
pngfile_zm = './pngs/landcover_ox_annual_mean_zm.png'

; get grid information
xarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/xmid) ; generate x grid for plotting
yarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/ymid) ; generate y grid for plotting

Map_Labels, LatLabel, LonLabel, $
Lats=Lats, LatRange=LatRange, $
Lons=Lons, LonRange=LonRange, $
NormLats=NormLats, NormLons=NormLons, $
/MapGrid, _EXTRA=e

open_device, ps=saveplot, filename=outfile, winparam=[0,1000,800], /color

; force reading of tracerinfo.dat and diaginfo.dat
ctm_tracerinfo, /all, /force_reading, filename = './tracerinfo.dat'
ctm_diaginfo, /all, /force_reading, filename = './diaginfo.dat'
   
; set ox data parameters
tracer = 2 ; Ox
diagn='IJ-AVG-$'
tau = nymd2tau( 20000101L, 0L )

; extract data set from bpch file
ctm_get_data, datainfo_ox2000, tracer=2, diagn='IJ-AVG-$', filename=data2000, /use_datainfo
ctm_get_data, datainfo_ox2050, tracer=2, diagn='IJ-AVG-$', filename=data2050, /use_datainfo
ctm_get_data, datainfo_ox2100, tracer=2, diagn='IJ-AVG-$', filename=data2100, /use_datainfo
help, datainfo_ox2000, /struc
help, (*(datainfo_ox2000[0].data))
; print, datainfo_ox2000.tracername
; print, datainfo_ox2000[0].tau0
; print, datainfo_ox2000[0].tau1

; print, TAU2YYMMDD(datainfo_ox2000[0].tau0)
; print, TAU2YYMMDD(datainfo_ox2000[0].tau1)

; extract the ox data
ox2000data = make_array(12L, 72L, 45L, 23L, /float)
ox2050data = make_array(12L, 72L, 45L, 23L, /float)
ox2100data = make_array(12L, 72L, 45L, 23L, /float)
j=0L
; 2000
for i=0, n_elements(datainfo_ox2000)-1L do begin
   if datainfo_ox2000[i].tracername eq 'Ox' AND j le 11L then begin
      ox2000data[j,*,*,*] = (*(datainfo_ox2000[i].data))[*,*,*]
      units2000 = datainfo_ox2000[i].unit
      ++j
   endif
endfor

; 2050
j=0L
for i=0, n_elements(datainfo_ox2050)-1L do begin
   if datainfo_ox2050[i].tracername eq 'Ox' AND j le 11L then begin
      ox2050data[j,*,*,*] = (*(datainfo_ox2050[i].data))[*,*,*]
      units2050 = datainfo_ox2050[i].unit
      ++j
   endif
endfor

; 2100
j=0L
for i=0, n_elements(datainfo_ox2100)-1L do begin
   if datainfo_ox2100[i].tracername eq 'Ox' AND j le 11L then begin
      ox2100data[j,*,*,*] = (*(datainfo_ox2100[i].data))[*,*,*]
      units2100 = datainfo_ox2100[i].unit
      ++j
   endif
endfor

IF units2000 ne units2050 OR units2000 ne units2100 then print, 'ERROR: units not the same!!!'

; calculate annual mean
ox_sum2000 = ox2000data[0,*,*,*]
ox_sum2050 = ox2050data[0,*,*,*]
ox_sum2100 = ox2100data[0,*,*,*]
for k=1, 11L do begin
   ox_sum2000 = ox_sum2000 + ox2000data[k,*,*,*] 
   ox_sum2050 = ox_sum2050 + ox2050data[k,*,*,*] 
   ox_sum2100 = ox_sum2100 + ox2100data[k,*,*,*] 
endfor
ox_avg_2000 = reform(ox_sum2000[0,*,*,*]/12.)
ox_avg_2050 = reform(ox_sum2050[0,*,*,*]/12.)
ox_avg_2100 = reform(ox_sum2100[0,*,*,*]/12.)

; generate plots
open_device, ps=saveplot, filename=outfile, winparam=[0,1000,800], /color
multipanel, rows=2, cols=2

MyCt, 33, ncolors=6,sat=1.0, value=1.0, bottom=18, range=[0.1, 1]

; plot 2000 veg
tvmap, ox_avg_2000[*,*,0], xarr1, yarr1, $
   position = [0.1, 0.02, 0.90, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.06, 0.95, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   ; c_levels = [0.050, 0.10, 0.20, 0.50, 1.0, 1.5], $
   c_levels = [0.0, 10.0, 20.0, 30.0, 40.0, 50.0], $
   ; toplevelvalue = 1.8, $
   toplevelvalue = 50., $
   cbunit = units2000, $
   cbformat = '(g7.2)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2000 veg'

myct, 'RdBu', /MIDCOLORPRESENT, /WHITE, ncolors=7, /reverse
; myct, 'Dark2', /MIDCOLORPRESENT, /WHITE, ncolors=7

; plot 2050 veg - 2000 veg
data = ox_avg_2050[*,*,0] - ox_avg_2000[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.02, 0.89, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.06, 0.94, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2050 veg - 2000 veg'
   
; plot 2100 veg - 2050 veg
data = ox_avg_2100[*,*,0] - ox_avg_2050[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.1, 0.1, 0.90, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.14, 0.95, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2100 veg - 2050 veg'


; plot 2100 veg - 2000 veg
data = ox_avg_2100[*,*,0] - ox_avg_2000[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.1, 0.89, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.14, 0.94, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2100 veg - 2000 veg'
   
if ( PNG ) then Screen2Png, pngfile
if ( saveplot ) then Close_Device

if ( do_zm ) then begin

   ; get grid information
   ModelType = 'GCAP'
   resolution = 4
   ModelInfo = CTM_TYPE( ModelType, reso=resolution)
   GridInfo  = CTM_GRID( ModelInfo )
   modellayers = 47 ; GEOS-5 reduced grid

   ; get grid information
   xarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/ymid) ; generate x grid for plotting
   yarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/pmid) ; generate y grid for plotting

   ; calculate zonal mean
   SD1 = size(ox_avg_2000, /DIM) ; array dimensions i-long, j-lat, k-layer
   data1=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
   data2=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
   data3=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
   data4=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
   ytop=SD1[2]-1
   ; average data over longitudes
   FOR j = 0, SD1[1]-1 DO BEGIN
      For k = 0, SD1[2] - 1 DO BEGIN
         data1[j,k] = total( ox_avg_2000[*,j,k]) / SD1[0]
         data2[j,k] = total( (ox_avg_2050[*,j,k] - ox_avg_2000[*,j,k]) ) / SD1[0]
         data3[j,k] = total( (ox_avg_2100[*,j,k] - ox_avg_2050[*,j,k]) ) / SD1[0]
         data4[j,k] = total( (ox_avg_2100[*,j,k] - ox_avg_2000[*,j,k]) ) / SD1[0]
      ENDFOR
   ENDFOR

   ; generate plots
   open_device, ps=saveplot, filename=outfile_zm, winparam=[1,1000,800], /color
   multipanel, rows=2, cols=2

   ; plot 2000 Ox annual avg zonal mean
   c_levels=[15., 30., 40., 50., 60., 100.]
   MyCt, 33, ncolors=6,sat=1.0, value=1.0, bottom=18, range=[0.1,1]
   ; margin=[0., 0., 0., 0.04] ; [left,bottom,right,top]
   tvplot, data1[*,0:ytop], xarr1, yarr1[0:ytop], $
      position = [0.2, 0.02, 0.86, 0.92], $ ; [left,bottom,right,top]
      cbposition = [0.88, 0.06, 0.91, 0.88], $ ; [left,bottom,right,top]
      /fcontour, $
      /cbar, $
      /cbvertical, $
      c_levels=c_levels, $
      csfac=1.35, $
      cbformat='(I3)', $
      title='2000 veg', $
      xticks=6, $
      xtickname =  [ ' ', ' ', ' ', ' ', ' ', ' ', ' ' ], $
      ytitle='Pressure (hPa)', $
      ystyle=1, $
      yticks=5, $
      ytickname = ['1000', '800', '600', '400', '200', ' '], $
      margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]
      
   myct, 'RdBu', /MIDCOLORPRESENT, /WHITE, ncolors=7, /reverse

   ; plot 2050 Ox / 2000 Ox annual avg zonal mean
   tvplot, data2(*,0:ytop), xarr1, yarr1[0:ytop], $
      position = [0.05, 0.02, 0.72, 0.92], $ ; [left,bottom,right,top]
      cbposition = [0.74, 0.06, 0.77, 0.88], $ ; [left,bottom,right,top]
      /fcontour, $
      /cbar, $
      /cbvertical, $
      c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
      csfac=1.35, $
      cbformat='(f7.1)', $
      title='2050 veg - 2000 veg', $
      xticks=6, $
      xtickname =  [ ' ', ' ', ' ', ' ', ' ', ' ', ' ' ], $
      ystyle=1, $
      yticks=5, $
      ytickname = [ ' ', ' ', ' ', ' ', ' ', ' ' ], $
      margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]

   ; plot 2100 Ox - 2050 Ox annual avg zonal mean
   tvplot, data3(*,0:ytop), xarr1, yarr1[0:ytop], $
      position = [0.2, 0.1, 0.86, 0.96], $ ; [left,bottom,right,top]
      cbposition = [0.88, 0.14, 0.91, 0.92], $ ; [left,bottom,right,top]
      /fcontour, $
      /cbar, $
      /cbvertical, $
      c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
      csfac=1.35, $
      cbformat='(f7.1)', $
      title='2100 veg - 2050 veg', $
      xticks=6, $
      xtickname = latlabel, $
      ytitle='Pressure (hPa)', $
      ystyle=1, $
      yticks=5, $
      ytickname = ['1000', '800', '600', '400', '200', ' '], $
      margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]

   ; plot 2100 Ox - 2000 Ox annual avgzonal mean
   tvplot, data4(*,0:ytop), xarr1, yarr1[0:ytop], $
      position = [0.05, 0.1, 0.72, 0.96], $ ; [left,bottom,right,top]
      cbposition = [0.74, 0.14, 0.77, 0.92], $ ; [left,bottom,right,top]
      /fcontour, $
      /cbar, $
      /cbvertical, $
      c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
      csfac=1.35, $
      cbformat='(f7.1)', $
      title='2100 veg - 2000 veg', $
      xticks=6, $
      xtickname = latlabel, $
      ystyle=1, $
      yticks=5, $
      ytickname = [ ' ', ' ', ' ', ' ', ' ', ' ' ], $
      margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]
   
   if ( PNG ) then Screen2Png, pngfile_zm
   if ( saveplot ) then Close_Device
endif


end
