pro soaplot

; data files
datadir = './'
data2000 = datadir + 'ctm.natveg2000.bpch'
data2050 = datadir + 'ctm.natveg2050.bpch'
data2100 = datadir + 'ctm.natveg2100.bpch'

; get grid information
ModelType = 'GCAP'
resolution = 4
ModelInfo = CTM_TYPE( ModelType, reso=resolution)
GridInfo  = CTM_GRID( ModelInfo )
modellayers = 47 ; GEOS-5 reduced grid

saveplot = 1L
png = 0L
outfile = './plots/landcover_soa.ps'
pngfile = './pngs/landcover_soa.png'

; get grid information
xarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/xmid) ; generate x grid for plotting
yarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/ymid) ; generate y grid for plotting

Map_Labels, LatLabel, LonLabel, $
Lats=Lats, LatRange=LatRange, $
Lons=Lons, LonRange=LonRange, $
NormLats=NormLats, NormLons=NormLons, $
/MapGrid, _EXTRA=e

open_device, ps=saveplot, filename=outfile, winparam=[0,1000,800], /color

; force reading of tracerinfo.dat and diaginfo.dat
ctm_tracerinfo, /all, /force_reading, filename = './tracerinfo.dat'
ctm_diaginfo, /all, /force_reading, filename = './diaginfo.dat'
   
; set SOA data parameters
tracer = 43006 ; sum of SOA1-4
; tracer = 6
diagn='IJ-SOA-$'
tau = nymd2tau( 20000101L, 0L )

; extract data set from bpch file
ctm_get_data, datainfosoa2000, tracer=43006, diagn='IJ-SOA-$', filename=data2000, /use_datainfo
ctm_get_data, datainfosoa2050, tracer=43006, diagn='IJ-SOA-$', filename=data2050, /use_datainfo
ctm_get_data, datainfosoa2100, tracer=43006, diagn='IJ-SOA-$', filename=data2100, /use_datainfo

; extract the SOA1-4 data
soa2000data = make_array(12L, 72L, 45L, 23L, /float)
soa2050data = make_array(12L, 72L, 45L, 23L, /float)
soa2100data = make_array(12L, 72L, 45L, 23L, /float)
j=0L
; 2000
for i=0, n_elements(datainfosoa2000)-1L do begin
   if datainfosoa2000[i].tracername eq 'SOA1-4' then begin
      soa2000data[j,*,*,*] = (*(datainfosoa2000[i].data))[*,*,*]
      units2000 = datainfosoa2000[i].unit
      ++j
   endif
endfor

; 2050
j=0L
for i=0, n_elements(datainfosoa2050)-1L do begin
   if datainfosoa2050[i].tracername eq 'SOA1-4' then begin
      soa2050data[j,*,*,*] = (*(datainfosoa2050[i].data))[*,*,*]
      units2050 = datainfosoa2050[i].unit
      ++j
   endif
endfor

; 2100
j=0L
for i=0, n_elements(datainfosoa2100)-1L do begin
   if datainfosoa2100[i].tracername eq 'SOA1-4' then begin
      soa2100data[j,*,*,*] = (*(datainfosoa2100[i].data))[*,*,*]
      units2100 = datainfosoa2100[i].unit
      ++j
   endif
endfor

IF units2000 ne units2050 OR units2000 ne units2100 then print, 'ERROR: units not the same!!!'

; calculate annual mean
soa_sum2000 = soa2000data[0,*,*,*]
soa_sum2050 = soa2050data[0,*,*,*]
soa_sum2100 = soa2100data[0,*,*,*]
for k=1, 11L do begin
   soa_sum2000 = soa_sum2000 + soa2000data[k,*,*,*] 
   soa_sum2050 = soa_sum2050 + soa2050data[k,*,*,*] 
   soa_sum2100 = soa_sum2100 + soa2100data[k,*,*,*] 
endfor
soa_avg_2000 = reform(soa_sum2000[0,*,*,*]/12.)
soa_avg_2050 = reform(soa_sum2050[0,*,*,*]/12.)
soa_avg_2100 = reform(soa_sum2100[0,*,*,*]/12.)

; generate plots

multipanel, rows=2, cols=2

MyCt, 33, ncolors=6,sat=1.0, value=1.0, bottom=18, range=[0.1, 1]

; plot 2000 veg
tvmap, soa_avg_2000[*,*,0], xarr1, yarr1, $
   position = [0.1, 0.02, 0.90, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.06, 0.95, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [0.050, 0.10, 0.20, 0.50, 1.0, 1.5], $
   toplevelvalue = 1.8, $
   cbunit = units2000, $
   cbformat = '(g7.2)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2000 veg'

myct, 'RdBu', /MIDCOLORPRESENT, /WHITE, ncolors=7, /reverse
; myct, 'Dark2', /MIDCOLORPRESENT, /WHITE, ncolors=7

; plot 2050 veg - 2000 veg
data = soa_avg_2050[*,*,0] - soa_avg_2000[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.02, 0.89, 0.94], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.06, 0.94, 0.90], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=1, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2050 veg - 2000 veg'
   
; plot 2100 veg - 2050 veg
data = soa_avg_2100[*,*,0] - soa_avg_2050[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.1, 0.1, 0.90, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.92, 0.14, 0.95, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.02, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=0, $ ; turn off y-axis labels
   title = '2100 veg - 2050 veg'


; plot 2100 veg - 2000 veg
data = soa_avg_2100[*,*,0] - soa_avg_2000[*,*,0]
tvmap, data, xarr1, yarr1, $
   position = [0.0, 0.1, 0.89, 1.0], $ ; [left,bottom,right,top]
   cbposition = [0.91, 0.14, 0.94, 0.96], $ ; [left,bottom,right,top]
   margin = [ 0.02, 0.02, 0.04, 0.03 ], $ ; [left,bottom,right,top]
   /continents, $
   /coasts, $
   /countries, $
   /cbar, $
   /fcontour, $
   Csfac = 1.35, $
   cbvertical=1, $
   c_levels = [-0.5, -0.2, -0.1, -0.05, 0.05, 0.1, 0.2], $
   toplevelvalue = 0.5, $
   cbunit = units2000, $
   cbformat = '(g7.1)', $
   nogxlabels=0, $ ; turn off x-axis labels
   nogylabels=1, $ ; turn off y-axis labels
   title = '2100 veg - 2000 veg'
   
if ( PNG ) then Screen2Png, pngfile
if ( saveplot ) then Close_Device
end
