pro zmoxplot_MAM, $
   multi=multi, $
   positioning=positioning

; data files
datadir = './'
data2000 = datadir + 'ctm.natveg2000.bpch'
data2050 = datadir + 'ctm.natveg2050.bpch'
data2100 = datadir + 'ctm.natveg2100.bpch'

; get grid information
ModelType = 'GCAP'
resolution = 4
ModelInfo = CTM_TYPE( ModelType, reso=resolution)
GridInfo  = CTM_GRID( ModelInfo )
modellayers = 47 ; GEOS-5 reduced grid

saveplot = 1L
png = 0L
outfile = './plots/landcover_ox_zm_MAM.ps'
pngfile = './pngs/landcover_ox_zm_MAM.png'

; get grid information
xarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/ymid) ; generate x grid for plotting
yarr1=ctm_grid(ctm_type(ModelType,reso=resolution,nlayers=modellayers),/pmid) ; generate y grid for plotting

Map_Labels, LatLabel, LonLabel, $
Lats=Lats, LatRange=LatRange, $
Lons=Lons, LonRange=LonRange, $
NormLats=NormLats, NormLons=NormLons, $
/MapGrid, _EXTRA=e

open_device, ps=saveplot, filename=outfile, winparam=[0,1000,800], /color

; set Ox data parameters
tracer=2 ; Ox
diagn='IJ-AVG-$'
tau_mar = nymd2tau( 20000301L, 0L )
tau_apr = nymd2tau( 20000401L, 0L )
tau_may = nymd2tau( 20000501L, 0L )

; extract data set from bpch file
ctm_get_data, datainfo2000_mar, tau0=tau_mar, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2000_apr, tau0=tau_apr, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2000_may, tau0=tau_may, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2050_mar, tau0=tau_mar, diagn=diagn, tracer=tracer, filename=data2050
ctm_get_data, datainfo2050_apr, tau0=tau_apr, diagn=diagn, tracer=tracer, filename=data2050
ctm_get_data, datainfo2050_may, tau0=tau_may, diagn=diagn, tracer=tracer, filename=data2000
ctm_get_data, datainfo2100_mar, tau0=tau_mar, diagn=diagn, tracer=tracer, filename=data2100
ctm_get_data, datainfo2100_apr, tau0=tau_apr, diagn=diagn, tracer=tracer, filename=data2100
ctm_get_data, datainfo2100_may, tau0=tau_may, diagn=diagn, tracer=tracer, filename=data2100

; extract data for each month
data_mar2000 = (*(datainfo2000_mar[0].data))[*,*,*,0,0,0]
data_apr2000 = (*(datainfo2000_apr[0].data))[*,*,*,0,0,0]
data_may2000 = (*(datainfo2000_may[0].data))[*,*,*,0,0,0]
data_mar2050 = (*(datainfo2050_mar[0].data))[*,*,*,0,0,0]
data_apr2050 = (*(datainfo2050_apr[0].data))[*,*,*,0,0,0]
data_may2050 = (*(datainfo2050_may[0].data))[*,*,*,0,0,0]
data_mar2100 = (*(datainfo2100_mar[0].data))[*,*,*,0,0,0]
data_apr2100 = (*(datainfo2100_apr[0].data))[*,*,*,0,0,0]
data_may2100 = (*(datainfo2100_may[0].data))[*,*,*,0,0,0]

; declare array to hold calculated average
avg2000_ox = make_array(72L,45L,23L, /float)
avg2050_ox = make_array(72L,45L,23L, /float)
avg2100_ox = make_array(72L,45L,23L, /float)

; loop through all elements in array and calculate 3-month average
for long = 0, 71L DO BEGIN
   for lat = 0, 44L DO BEGIN
      for lev = 0, 22L DO BEGIN
           avg2000_ox[long, lat, lev] = mean([data_mar2000[long, lat, lev], data_apr2000[long, lat, lev], data_may2000[long, lat, lev]])
           avg2050_ox[long, lat, lev] = mean([data_mar2050[long, lat, lev], data_apr2050[long, lat, lev], data_may2050[long, lat, lev]])
           avg2100_ox[long, lat, lev] = mean([data_mar2100[long, lat, lev], data_apr2100[long, lat, lev], data_may2100[long, lat, lev]])
      endfor
   endfor
endfor

; calculate zonal mean
SD1 = size(avg2000_ox, /DIM) ; array dimensions i-long, j-lat, k-layer
data1=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
data2=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
data3=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
data4=fltarr(SD1[1], SD1[2]) ; declare new array to hold zonal mean data
ytop=SD1[2]-1
; average data over longitudes
FOR j = 0, SD1[1]-1 DO BEGIN
   For k = 0, SD1[2] - 1 DO BEGIN
      data1[j,k] = total( avg2000_ox[*,j,k]) / SD1[0]
      data2[j,k] = total( (avg2050_ox[*,j,k] - avg2000_ox[*,j,k]) ) / SD1[0]
      data3[j,k] = total( (avg2100_ox[*,j,k] - avg2050_ox[*,j,k]) ) / SD1[0]
      data4[j,k] = total( (avg2100_ox[*,j,k] - avg2000_ox[*,j,k]) ) / SD1[0]
   ENDFOR
ENDFOR

; generate plots

multipanel, rows=2, cols=2

; plot 2000 ox zonal mean
c_levels=[15., 30., 40., 50., 60., 100.]
MyCt, 33, ncolors=6,sat=1.0, value=1.0, bottom=18, range=[0.1,1]
; margin=[0., 0., 0., 0.04] ; [left,bottom,right,top]
tvplot, data1[*,0:ytop], xarr1, yarr1[0:ytop], $
   position = [0.2, 0.02, 0.86, 0.92], $ ; [left,bottom,right,top]
   cbposition = [0.88, 0.06, 0.91, 0.88], $ ; [left,bottom,right,top]
   /fcontour, $
   /cbar, $
   /cbvertical, $
   c_levels=c_levels, $
   csfac=1.35, $
   cbformat='(I3)', $
   title='2000 veg', $
   xticks=6, $
   xtickname =  [ ' ', ' ', ' ', ' ', ' ', ' ', ' ' ], $
   ytitle='Pressure (hPa)', $
   ystyle=1, $
   yticks=5, $
   ytickname = ['1000', '800', '600', '400', '200', ' '], $
   margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]
   
myct, 'RdBu', /MIDCOLORPRESENT, /WHITE, ncolors=7, /reverse

; plot 2050 ox / 2000 ox zonal mean
tvplot, data2(*,0:ytop), xarr1, yarr1[0:ytop], $
   position = [0.05, 0.02, 0.72, 0.92], $ ; [left,bottom,right,top]
   cbposition = [0.74, 0.06, 0.77, 0.88], $ ; [left,bottom,right,top]
   /fcontour, $
   /cbar, $
   /cbvertical, $
   c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
   csfac=1.35, $
   cbformat='(f7.1)', $
   title='2050 veg - 2000 veg', $
   xticks=6, $
   xtickname =  [ ' ', ' ', ' ', ' ', ' ', ' ', ' ' ], $
   ystyle=1, $
   yticks=5, $
   ytickname = [ ' ', ' ', ' ', ' ', ' ', ' ' ], $
   margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]

; plot 2100 Ox - 2050 Ox zonal mean
tvplot, data3(*,0:ytop), xarr1, yarr1[0:ytop], $
   position = [0.2, 0.1, 0.86, 0.96], $ ; [left,bottom,right,top]
   cbposition = [0.88, 0.14, 0.91, 0.92], $ ; [left,bottom,right,top]
   /fcontour, $
   /cbar, $
   /cbvertical, $
   c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
   csfac=1.35, $
   cbformat='(f7.1)', $
   title='2100 veg - 2050 veg', $
   xticks=6, $
   xtickname = latlabel, $
   ytitle='Pressure (hPa)', $
   ystyle=1, $
   yticks=5, $
   ytickname = ['1000', '800', '600', '400', '200', ' '], $
   margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]

; plot 2100 Ox - 2000 Ox zonal mean
tvplot, data4(*,0:ytop), xarr1, yarr1[0:ytop], $
   position = [0.05, 0.1, 0.72, 0.96], $ ; [left,bottom,right,top]
   cbposition = [0.74, 0.14, 0.77, 0.92], $ ; [left,bottom,right,top]
   /fcontour, $
   /cbar, $
   /cbvertical, $
   c_levels=[ -3.0, -2.0, -1.0, -0.5, 0.5, 1.0, 2.0 ], $
   csfac=1.35, $
   cbformat='(f7.1)', $
   title='2100 veg - 2000 veg', $
   xticks=6, $
   xtickname = latlabel, $
   ystyle=1, $
   yticks=5, $
   ytickname = [ ' ', ' ', ' ', ' ', ' ', ' ' ], $
   margin = [0., 0., 0., 0.04] ; [left,bottom,right,top]
   
if ( PNG ) then Screen2Png, pngfile
if ( saveplot ) then Close_Device
end
